﻿using System;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Windows;
using System.Windows.Controls;

namespace ChartInTabControl
{
    public partial class DeviceWindow : UserControl, INotifyPropertyChanged
    {
        #region BOUND GRAPH AXIS PROPERTIES
        public event PropertyChangedEventHandler PropertyChanged;
        private double _W1MaxValue;
        public double W1MaxValue
        {
            get { return _W1MaxValue; }
            set { _W1MaxValue = value; NotifyPropertyChanged("W1MaxValue"); }
        }
        private double _W1MinValue;
        public double W1MinValue
        {
            get { return _W1MinValue; }
            set { _W1MinValue = value; NotifyPropertyChanged("W1MinValue"); }
        }
        const double W1MINDEFAULT = -1.5;
        const double W1MAXDEFAULT = 1.5;

        private double _W2MaxValue;
        public double W2MaxValue
        {
            get { return _W2MaxValue; }
            set { _W2MaxValue = value; NotifyPropertyChanged("W2MaxValue"); }
        }
        private double _W2MinValue;
        public double W2MinValue
        {
            get { return _W2MinValue; }
            set { _W2MinValue = value; NotifyPropertyChanged("W2MinValue"); }
        }
        const double W2MINDEFAULT = -5;
        const double W2MAXDEFAULT = 5;


        const int MAXBUFFERLENGTH = 50;
        #endregion
        public static ObservableCollection<GraphData> ECGPoints;
        public static ObservableCollection<GraphData> IppvPressPoints;

        public DeviceWindow()
        {
            InitializeComponent();
            InitializeGraphSeries();
        }
        void NotifyPropertyChanged(string info)
        {
            PropertyChanged?.Invoke(this, new PropertyChangedEventArgs(info));
        }
        void InitializeGraphSeries()
        {
            ECGPoints = new ObservableCollection<GraphData>();
            ECGSeries.ItemsSource = ECGPoints;
            ECGSeries.ListenPropertyChange = true;
            ECGSeries.XBindingPath = "XValue";
            ECGSeries.YBindingPath = "YValue";
            W1MinValue = W1MINDEFAULT;
            W1MaxValue = W1MAXDEFAULT;

            IppvPressPoints = new ObservableCollection<GraphData>();
            IppvPressSeries.ItemsSource = IppvPressPoints;
            IppvPressSeries.ListenPropertyChange = true;
            IppvPressSeries.XBindingPath = "XValue";
            IppvPressSeries.YBindingPath = "YValue";
            W2MinValue = W2MINDEFAULT;
            W2MaxValue = W2MAXDEFAULT;

        }
        void StartStopButton_Click(object sender, RoutedEventArgs e)
        {
            Simulator.WaveformTimer.IsEnabled = !Simulator.WaveformTimer.IsEnabled;
            StartStopButton.Content = (Simulator.WaveformTimer.IsEnabled) ? "STOP" : "START";
        }
    }
    public class GraphData : INotifyPropertyChanged
    {
        private double _YValue;
        public double YValue
        {
            get { return _YValue; }
            set { _YValue = value; NotifyPropertyChanged("YValue"); }
        }
        public double XValue { get; set; }

        public event PropertyChangedEventHandler PropertyChanged;
        private void NotifyPropertyChanged(String info)
        {
            PropertyChanged?.Invoke(this, new PropertyChangedEventArgs(info));
        }
    }
}
