﻿using System;
using System.ComponentModel;
using System.Windows;
using System.Windows.Threading;

namespace ChartInTabControl
{
    public partial class Simulator : Window, INotifyPropertyChanged
    {
        public static DispatcherTimer WaveformTimer;
        public event PropertyChangedEventHandler PropertyChanged;
        int XAxisIndex;
        const int MAXXAXIS = 500;
        public Simulator()
        {
            InitializeComponent();
            InitializeStructures();
        }
        void InitializeStructures()
        {
            WaveformTimer = new DispatcherTimer(DispatcherPriority.Send);
            WaveformTimer.Interval = TimeSpan.FromMilliseconds(20);
            WaveformTimer.Tick += new EventHandler(WaveformTimer_Tick);
        }
        void WaveformTimer_Tick(object sender, EventArgs e)
        {
            MakeGraphData();
        }
        void MakeGraphData()
        {
            Random r = new Random();
            double rDouble = r.NextDouble() * 2;
            double ECGValue = rDouble - 1;
            if (DeviceWindow.ECGPoints.Count < MAXXAXIS)
            {
                var val = new GraphData();
                val.YValue = ECGValue;
                val.XValue = XAxisIndex;
                DeviceWindow.ECGPoints.Add(val);
                DeviceWindow.IppvPressPoints.Add(val);
            }
            else
            {
                XAxisIndex = (XAxisIndex < MAXXAXIS) ? XAxisIndex : 0;
                int NullPoint = (XAxisIndex < (MAXXAXIS - 1)) ? XAxisIndex + 1 : 0;
                DeviceWindow.ECGPoints[XAxisIndex].YValue = ECGValue;
                DeviceWindow.ECGPoints[NullPoint].YValue = double.NaN;

                DeviceWindow.IppvPressPoints[XAxisIndex].YValue = ECGValue;
                DeviceWindow.IppvPressPoints[NullPoint].YValue = double.NaN;
            }
            XAxisIndex++;
        }
        void NotifyPropertyChanged(string info)
        {
            PropertyChanged?.Invoke(this, new PropertyChangedEventArgs(info));
        }
    }
}
